@@ -1,3 +1,4 @@
+from collections import namedtuple
 from concurrent import futures
 import multiprocessing
 from itertools import chain, imap, izip
@@ -8,6 +9,10 @@ from UserString import UserString
 
 Pool = futures.ProcessPoolExecutor()
 
+'''Helper for the filter methods.
+This is a container of the result of some_evaluation(arg) and arg itself.'''
+EvalResult = namedtuple('EvalResult', ['bool', 'item'])
+
 
 def _map(fn, *iterables):
     '''using our own internal map function to avoid evaluation 
@@ -23,11 +28,17 @@ class _Filter(object):
     pickled and sent to other processes'''
     
     def __init__(self, predicate):
-        self.predicate = predicate
+        if predicate is None:
+            self.predicate = bool
+        else:
+            self.predicate = predicate
         
     def __call__(self, item):
         if self.predicate(item):
-            return item
+            return EvalResult(bool=True, item=item)
+        else:
+            return EvalResult(bool=False, item=None)
+
         
             
 class _Reducer(object):
@@ -62,7 +73,7 @@ class ParallelGen(object):
         
     def filter(self, pred):
         _filter = _Filter(pred)
-        return self.__class__((i for i in _map(_filter, self, ) if i is not None))
+        return self.__class__((i.item for i in _map(_filter, self, ) if i.bool))
         
     def flatten(self):
         '''if the data source consists of several sequences, those will be chained in one'''
